#!/bin/bash
#

#
# cython is a product that is always built unqualified
#
# build_cython.sh  <product_directory> [tar]

usage()
{
   echo "USAGE: `basename ${0}` <product_directory> <p2711> [tar]"
}

# -------------------------------------------------------------------
# shared boilerplate
# -------------------------------------------------------------------

die()
{
    local exitval
    if [[ "$1" =~ ^[0-9]*$ ]]; then (( exitval = $1 )); shift; else (( exitval = 1 )); fi
    echo "ERROR: $@" 1>&2
    exit $exitval
}

get_this_dir() 
{
    ( cd / ; /bin/pwd -P ) >/dev/null 2>&1
    if (( $? == 0 )); then
      pwd_P_arg="-P"
    fi
    reldir=`dirname ${0}`
    thisdir=`cd ${reldir} && /bin/pwd ${pwd_P_arg}`
}

get_ssibuildshims()
{
    # make sure we can use the setup alias
    if [ -z ${UPS_DIR} ]
    then
       echo "ERROR: please setup ups"
       exit 1
    fi
    source `${UPS_DIR}/bin/ups setup ${SETUP_UPS}`
    
    setup ssibuildshims ${ssibuildshims_version} -z ${product_dir}
}

get_platform_name()
{
    OS1=`uname`
    flvr=`ups flavor`
    if [ ${OS1} = "Darwin" ]
    then
	flvr=`ups flavor -2`
    fi
    OS=`${SSIBUILDSHIMS_DIR}/bin/get_os_platform`
    plat=`${SSIBUILDSHIMS_DIR}/bin/get_os_platform osplat`

    if [ -z ${flvr} ]
    then
       echo "ERROR: could not determine flavor for this platform"
       echo "       something is very wrong"
       exit 1
    fi

    pkgdir=${product_dir}/${package}/${pkgver}
    patchdir=${product_dir}/${package}/${pkgver}/patch
    blddir=${product_dir}/${package}/${pkgver}/build
    tardir=${product_dir}/${package}/${pkgver}/tar
    sourcedir=${product_dir}/${package}/${pkgver}/source
}

# -------------------------------------------------------------------
# start processing
# -------------------------------------------------------------------

product_dir=${1}
pqual=${2}
maketar=${3}

if [ -z ${product_dir} ]
then
   echo "ERROR: please specify the local product directory" 1>&2
   usage
   exit 1
fi

if [[ -z "${pqual}" ]] || [[ "${pqual}" == "tar" ]]
then
  echo "Python qualifier is mandatory." 1>&2
  usage
  exit 1
fi

# -------------------------------------------------------------------
# package name and version
# -------------------------------------------------------------------

package=cython
origpkgver=v0_24_1
pkgver=${origpkgver}
ssibuildshims_version=v0_11_00
pkgdotver=`echo ${origpkgver} | sed -e 's/_/./g' -e 's/^v//'`
pkgtarname=${package}-${pkgdotver}
make_tarball_opts=(-F -d bin:lib "${product_dir}" "${package}" "${pkgver}" "${pqual}" NO_FLAVOR)

get_this_dir
get_ssibuildshims
get_platform_name
set -x
if [ "${maketar}" = "tar" ] && [ -f ${pkgdir}.version/NULL_${pqual} ]
then
   ${SSIBUILDSHIMS_DIR}/bin/make_distribution_tarball "${make_tarball_opts[@]}"
   exit 0
fi
set +x
echo "building ${package} for ${OS}-${plat}"

# -------------------------------------------------------------------
# package dependent stuff goes here
# -------------------------------------------------------------------

mkdir -p ${blddir} 
if [ ! -d ${blddir} ]
then
   echo "ERROR: failed to create ${blddir}"
   exit 1
fi

if [ ${OS1} = "Darwin" ]
then
   PATH=`dropit /usr/bin/get-cert $PATH`
fi

# declare now so we can setup
# fake ups declare
fakedb=${product_dir}/${package}/${pkgver}/fakedb
${SSIBUILDSHIMS_DIR}/bin/fake_declare_product ${product_dir} ${package} ${pkgver} ${pqual} NO_FLAVOR

# setup
setup -B ${package} ${pkgver} -q ${pqual} -z ${fakedb}:${product_dir}:${PRODUCTS} || die "fake setup failed"

set -x

# work in a build directory, which will not be part of any distribution
cd ${blddir} || die "Unable to cd into ${blddir}"
# The tarball is Cython..., no cython...
tar xf ${tardir}/Cython-${pkgdotver}.tar.gz || die "Failed to untar $Cython-{pkgdotver}.tar.gz"
cd Cython-${pkgdotver} || die "Failed to cd into $Cython-${pkgdotver}"
python setup.py install --prefix ${pkgdir} --single-version-externally-managed --root "/" || die "python setup.py install failed"

set +x

if [ ! -d ${pkgdir}/lib ]
then
   echo "ERROR: failed to create ${pkgdir}/lib"
   echo "       Something is very wrong"
   exit 1
fi

#replace hardwired python path 
sed -i'' -e '1s/^.*$/#!\/usr\/bin\/env python /' ${pkgdir}/bin/cygdb || die "Failed to fix shebang for cygdb"
sed -i'' -e '1s/^.*$/#!\/usr\/bin\/env python /' ${pkgdir}/bin/cython || die "Failed to fix shebang for cython"
sed -i'' -e '1s/^.*$/#!\/usr\/bin\/env python /' ${pkgdir}/bin/cythonize || die "Failed to fix shebang for cythonize"

# real ups declare
${SSIBUILDSHIMS_DIR}/bin/declare_product ${product_dir} ${package} ${pkgver} ${pqual} NO_FLAVOR || die "failed to declare ${package} ${pkgver}"

# -------------------------------------------------------------------
# common bottom stuff
# -------------------------------------------------------------------

# this should not complain
echo "Finished building ${package} ${pkgver}"
setup -B ${package} ${pkgver} -q ${pqual} -z ${product_dir}
echo "cython is installed at ${CYTHON_DIR}"

# this must be last

if [ "${maketar}" = "tar" ] &&  [ -f ${pkgdir}.version/NULL_${pqual} ]
then
   ${SSIBUILDSHIMS_DIR}/bin/make_distribution_tarball "${make_tarball_opts[@]}"
fi

exit 0
